import { isBrowser } from "../functions/is-browser.qwik.mjs";
import { setCookie, getCookieSync } from "./cookie.qwik.mjs";
const USER_ATTRIBUTES_COOKIE_NAME = "builder.userAttributes";
function createUserAttributesService() {
  let canTrack = true;
  const subscribers = /* @__PURE__ */ new Set();
  return {
    setUserAttributes(newAttrs) {
      if (!isBrowser())
        return;
      const userAttributes = {
        ...this.getUserAttributes(),
        ...newAttrs
      };
      setCookie({
        name: USER_ATTRIBUTES_COOKIE_NAME,
        value: JSON.stringify(userAttributes),
        canTrack
      });
      subscribers.forEach((callback) => callback(userAttributes));
    },
    getUserAttributes() {
      if (!isBrowser())
        return {};
      return JSON.parse(getCookieSync({
        name: USER_ATTRIBUTES_COOKIE_NAME,
        canTrack
      }) || "{}");
    },
    subscribeOnUserAttributesChange(callback) {
      subscribers.add(callback);
      return () => {
        subscribers.delete(callback);
      };
    },
    setCanTrack(value) {
      canTrack = value;
    }
  };
}
const userAttributesService = createUserAttributesService();
const setClientUserAttributes = (attributes) => {
  userAttributesService.setUserAttributes(attributes);
};
export {
  USER_ATTRIBUTES_COOKIE_NAME,
  createUserAttributesService,
  setClientUserAttributes,
  userAttributesService
};
