"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const isBrowser = require("../functions/is-browser.qwik.cjs");
const isFromTrustedHost = require("../functions/is-from-trusted-host.qwik.cjs");
const initEditing = require("../scripts/init-editing.qwik.cjs");
const logger = require("./logger.qwik.cjs");
const createEditorListener = ({ model, trustedHosts, callbacks }) => {
  return (event) => {
    if (!isFromTrustedHost.isFromTrustedHost(trustedHosts, event))
      return;
    const { data } = event;
    if (data)
      switch (data.type) {
        case "builder.configureSdk":
          callbacks.configureSdk(data.data);
          break;
        case "builder.triggerAnimation":
          callbacks.animation(data.data);
          break;
        case "builder.resetState": {
          const messageContent = data.data;
          const modelName = messageContent.model;
          const newState = messageContent == null ? void 0 : messageContent.state;
          if (modelName === model && newState)
            callbacks.stateUpdate(newState);
          break;
        }
        case "builder.contentUpdate": {
          const messageContent = data.data;
          const key = messageContent.key || messageContent.alias || messageContent.entry || messageContent.modelName;
          const contentData = messageContent.data;
          if (key === model)
            callbacks.contentUpdate(contentData);
          break;
        }
      }
  };
};
const subscribeToEditor = ({ model, apiKey, callback, trustedHosts }) => {
  if (!isBrowser.isBrowser) {
    logger.logger.warn("`subscribeToEditor` only works in the browser. It currently seems to be running on the server.");
    return () => {
    };
  }
  initEditing.setupBrowserForEditing({
    modelName: model,
    apiKey
  });
  const listener = createEditorListener({
    callbacks: {
      contentUpdate: callback,
      animation: () => {
      },
      configureSdk: () => {
      },
      stateUpdate: () => {
      }
    },
    model,
    trustedHosts
  });
  window.addEventListener("message", listener);
  return () => {
    window.removeEventListener("message", listener);
  };
};
exports.createEditorListener = createEditorListener;
exports.subscribeToEditor = subscribeToEditor;
