"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const target = require("../../constants/target.qwik.cjs");
const abTests = require("../../helpers/ab-tests.qwik.cjs");
const canTrack = require("../../helpers/canTrack.qwik.cjs");
const logger = require("../../helpers/logger.qwik.cjs");
const sdkHeaders = require("../../helpers/sdk-headers.qwik.cjs");
const getFetch = require("../get-fetch.qwik.cjs");
const isBrowser = require("../is-browser.qwik.cjs");
const generateContentUrl = require("./generate-content-url.qwik.cjs");
const checkContentHasResults = (content) => "results" in content;
async function fetchOneEntry(options) {
  const allContent = await fetchEntries({
    ...options,
    limit: 1
  });
  if (allContent)
    return allContent[0] || null;
  return null;
}
const _fetchContent = async (options) => {
  var _a;
  const url = generateContentUrl.generateContentUrl(options);
  const _fetch = options.fetch ?? getFetch.fetch;
  const fetchOptions = {
    ...options.fetchOptions,
    headers: {
      ...(_a = options.fetchOptions) == null ? void 0 : _a.headers,
      ...sdkHeaders.getSdkHeaders()
    }
  };
  const res = await _fetch(url.href, fetchOptions);
  const content = await res.json();
  return content;
};
const _processContentResult = async (options, content, url = generateContentUrl.generateContentUrl(options)) => {
  const canTrack$1 = canTrack.getDefaultCanTrack(options.canTrack);
  url.search.includes(`preview=`);
  if (!canTrack$1)
    return content.results;
  if (!(isBrowser.isBrowser() || target.TARGET === "reactNative"))
    return content.results;
  try {
    const newResults = [];
    for (const item of content.results)
      newResults.push(await abTests.handleABTesting({
        item,
        canTrack: canTrack$1
      }));
    content.results = newResults;
  } catch (e) {
    logger.logger.error("Could not process A/B tests. ", e);
  }
  return content.results;
};
async function fetchEntries(options) {
  const url = generateContentUrl.generateContentUrl(options);
  const content = await _fetchContent(options);
  if (!checkContentHasResults(content)) {
    logger.logger.error("Error fetching data. ", {
      url,
      content,
      options
    });
    throw content;
  }
  return _processContentResult(options, content);
}
exports._processContentResult = _processContentResult;
exports.fetchEntries = fetchEntries;
exports.fetchOneEntry = fetchOneEntry;
